def hello() -> str:
    return "Hello, world!"
# Check out
#    https://github.com/alphanome-ai/sec-parser
# where the majority of the development is happening right now.
# We'll get back to sec-ai once sec-parser is more ready.
